@@ -15,7 +15,7 @@ def push_branch(m:str,b:str,**url:str) -> str:
         cmd_branch = "git checkout {} ".format(b)
         cmd_message = 'git commit -m "{}"'.format(m)
         cmd_push = "git push origin {}".format(b)
-        if(b=="master" or b=="main" and m=="initial commit"):
+        if(b=="master" or b=="main" or m=="initial commit"):
             subprocess.getoutput('git init')
             subprocess.getoutput("git add .")  
             subprocess.getoutput(cmd_remote)
@@ -26,9 +26,11 @@ def push_branch(m:str,b:str,**url:str) -> str:
             result = subprocess.getoutput(cmd_push)
             return  result
         else:
-            subprocess.getoutput(cmd_branch)     
+            subprocess.getoutput(cmd_branch)  
+            print(cmd_branch)   
             subprocess.getoutput("git add -u")
             subprocess.getoutput(cmd_message)
+            print(cmd_message)
             result = subprocess.getoutput(cmd_push) 
             return  result
     except Exception as ex:
